[Scummvm-git-logs] scummvm master -> a461a39e4a864a0e850e72322e8771db188b7d4a

dreammaster dreammaster at scummvm.org
Tue Mar 6 03:46:50 CET 2018


This automated email contains information about 1 new commit which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
a461a39e4a XEEN: Fix shadowed field warning


Commit: a461a39e4a864a0e850e72322e8771db188b7d4a
    https://github.com/scummvm/scummvm/commit/a461a39e4a864a0e850e72322e8771db188b7d4a
Author: Paul Gilbert (dreammaster at scummvm.org)
Date: 2018-03-05T21:46:46-05:00

Commit Message:
XEEN: Fix shadowed field warning

Changed paths:
    engines/xeen/screen.cpp
    engines/xeen/screen.h


diff --git a/engines/xeen/screen.cpp b/engines/xeen/screen.cpp
index 8dc7ec8..c9781b3 100644
--- a/engines/xeen/screen.cpp
+++ b/engines/xeen/screen.cpp
@@ -163,14 +163,14 @@ void Screen::restoreBackground(int slot) {
 	blitFrom(_savedScreens[slot - 1]);
 }
 
-bool Screen::doScroll(bool rollUp, bool fadeIn) {
+bool Screen::doScroll(bool rollUp, bool fadeInFlag) {
 	Screen &screen = *_vm->_screen;
 	EventsManager &events = *_vm->_events;
 	const int SCROLL_L[8] = { 29, 23, 15, -5, -11, -23, -49, -71 };
 	const int SCROLL_R[8] = { 165, 171, 198, 218, 228, 245, 264, 281 };
 
 	if (_vm->_files->_isDarkCc) {
-		if (fadeIn)
+		if (fadeInFlag)
 			screen.fadeIn(2);
 		return _vm->shouldExit();
 	}
@@ -212,7 +212,7 @@ bool Screen::doScroll(bool rollUp, bool fadeIn) {
 			while (!_vm->shouldExit() && events.timeElapsed() == 0)
 				events.pollEventsAndWait();
 
-			if (i == 0 && fadeIn)
+			if (i == 0 && fadeInFlag)
 				screen.fadeIn(2);
 		}
 	} else {
@@ -237,7 +237,7 @@ bool Screen::doScroll(bool rollUp, bool fadeIn) {
 			while (!_vm->shouldExit() && events.timeElapsed() == 0)
 				events.pollEventsAndWait();
 
-			if (i == 0 && fadeIn)
+			if (i == 0 && fadeInFlag)
 				screen.fadeIn(2);
 		}
 	}
diff --git a/engines/xeen/screen.h b/engines/xeen/screen.h
index 3e7f23e..40b6958 100644
--- a/engines/xeen/screen.h
+++ b/engines/xeen/screen.h
@@ -115,11 +115,11 @@ public:
 
 	/**
 	 * Draws the scroll in the background
 	 * @param rollUp	If true, rolls up the scroll. If false, unrolls.
 	 * @param fadeIn	If true, does an initial fade in
 	 * @returns		True if key or mouse pressed
 	 */
-	bool doScroll(bool rollUp, bool fadeIn);
+	bool doScroll(bool rollUp, bool fadeInFlag);
 };
 
 } // End of namespace Xeen
@@ -115,11 +115,11 @@ public:
 	/**
 	 * Draws the scroll in the background
-	 * @param rollUp	If true, rolls up the scroll. If false, unrolls.
-	 * @param fadeIn	If true, does an initial fade in
+	 * @param rollUp		If true, rolls up the scroll. If false, unrolls.
+	 * @param fadeInFlag	If true, does an initial fade in
 	 * @returns		True if key or mouse pressed
 	 */





More information about the Scummvm-git-logs mailing list